==> zio-aws-evidently_2.12-5.17.112.1-sources.jar: zio/aws/evidently/model/ExperimentExecution.scala <==
package zio.aws.evidently.model
import zio.aws.evidently.model.primitives.Timestamp
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class ExperimentExecution(
    endedTime: Option[Timestamp] = None,
    startedTime: Option[Timestamp] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.evidently.model.ExperimentExecution = {
    import ExperimentExecution.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.evidently.model.ExperimentExecution
      .builder()
      .optionallyWith(endedTime.map(value => Timestamp.unwrap(value): Instant))(
        _.endedTime
      )
      .optionallyWith(
        startedTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.startedTime)
      .build()
  }
  def asReadOnly: zio.aws.evidently.model.ExperimentExecution.ReadOnly =
    zio.aws.evidently.model.ExperimentExecution.wrap(buildAwsValue())
}
object ExperimentExecution {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.evidently.model.ExperimentExecution
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.evidently.model.ExperimentExecution =
      zio.aws.evidently.model.ExperimentExecution(
        endedTime.map(value => value),
        startedTime.map(value => value)
      )
    def endedTime: Option[Timestamp]
    def startedTime: Option[Timestamp]
    def getEndedTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("endedTime", endedTime)
    def getStartedTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("startedTime", startedTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.evidently.model.ExperimentExecution
  ) extends zio.aws.evidently.model.ExperimentExecution.ReadOnly {
    override val endedTime: Option[Timestamp] = scala
      .Option(impl.endedTime())
      .map(value => zio.aws.evidently.model.primitives.Timestamp(value))
    override val startedTime: Option[Timestamp] = scala
      .Option(impl.startedTime())
      .map(value => zio.aws.evidently.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.evidently.model.ExperimentExecution
  ): zio.aws.evidently.model.ExperimentExecution.ReadOnly = new Wrapper(impl)
}

==> zio-aws-evidently_2.12-5.17.197.2-sources.jar: zio/aws/evidently/model/ExperimentExecution.scala <==
package zio.aws.evidently.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.evidently.model.primitives.Timestamp
import scala.jdk.CollectionConverters._
final case class ExperimentExecution(
    endedTime: Optional[Timestamp] = Optional.Absent,
    startedTime: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.evidently.model.ExperimentExecution = {
    import ExperimentExecution.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.evidently.model.ExperimentExecution
      .builder()
      .optionallyWith(endedTime.map(value => Timestamp.unwrap(value): Instant))(
        _.endedTime
      )
      .optionallyWith(
        startedTime.map(value => Timestamp.unwrap(value): Instant)
      )(_.startedTime)
      .build()
  }
  def asReadOnly: zio.aws.evidently.model.ExperimentExecution.ReadOnly =
    zio.aws.evidently.model.ExperimentExecution.wrap(buildAwsValue())
}
object ExperimentExecution {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.evidently.model.ExperimentExecution
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.evidently.model.ExperimentExecution =
      zio.aws.evidently.model.ExperimentExecution(
        endedTime.map(value => value),
        startedTime.map(value => value)
      )
    def endedTime: Optional[Timestamp]
    def startedTime: Optional[Timestamp]
    def getEndedTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("endedTime", endedTime)
    def getStartedTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("startedTime", startedTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.evidently.model.ExperimentExecution
  ) extends zio.aws.evidently.model.ExperimentExecution.ReadOnly {
    override val endedTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.endedTime())
      .map(value => zio.aws.evidently.model.primitives.Timestamp(value))
    override val startedTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.startedTime())
      .map(value => zio.aws.evidently.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.evidently.model.ExperimentExecution
  ): zio.aws.evidently.model.ExperimentExecution.ReadOnly = new Wrapper(impl)
}
